==> lebiniou_3.31.orig.tar.gz: lebiniou-3.31/plugins/stable/main/tv_diff3/tv_diff3.c <==
/*
 *  Copyright 1994-2019 Olivier Girondel
 *  Copyright 2019 Tavasti
 *
 *  This file is part of lebiniou.
 *
 *  lebiniou is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  lebiniou is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with lebiniou. If not, see <http://www.gnu.org/licenses/>.
 */

#include "context.h"

#define MIN_DIFFERENCE 40 /* how much color value has to differ from initial
                             to be shown. Lower values show target better,
                             but also show more flickering */

u_long id = 1552077700;
u_long options = BE_GFX|BE_LENS|BEQ_IMAGE|BEQ_MUTE_CAM|BEQ_NORANDOM;
char desc[] = "Show cam pic which differs";
u_long mode = OVERLAY;


void
create(Context_t *ctx)
{
  if (!ctx->webcams) {
    options |= BEQ_DISABLED;
  }
}


void
run(Context_t *ctx)
{
  Pixel_t *src1, *start, *src2, *dst;

  dst = start = passive_buffer(ctx)->buffer;

  pthread_mutex_lock(&ctx->cam_mtx[ctx->cam]);
  src1 = ctx->cam_save[ctx->cam][0]->buffer;
  src2 = ctx->cam_ref0[ctx->cam]->buffer;
  for (; dst < start + BUFFSIZE * sizeof(Pixel_t); src1++, src2++, dst++) {
    if (((*src1 - *src2) > MIN_DIFFERENCE) ||
        ((*src2 - *src1) > MIN_DIFFERENCE) ) {
      *dst = abs(*src1 - *src2);
    } else {
      *dst = 0;
    }
  }
  pthread_mutex_unlock(&ctx->cam_mtx[ctx->cam]);
}

==> lebiniou_3.32.orig.tar.gz: lebiniou-3.32/plugins/stable/main/tv_diff3/tv_diff3.c <==
/*
 *  Copyright 1994-2019 Olivier Girondel
 *  Copyright 2019 Tavasti
 *
 *  This file is part of lebiniou.
 *
 *  lebiniou is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  lebiniou is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with lebiniou. If not, see <http://www.gnu.org/licenses/>.
 */

#include "context.h"

#define MIN_DIFFERENCE 40 /* how much color value has to differ from initial
                             to be shown. Lower values show target better,
                             but also show more flickering */

u_long id = 1552077700;
u_long options = BE_GFX|BE_LENS|BEQ_MUTE_CAM|BEQ_NORANDOM;
char desc[] = "Show cam pic which differs";
u_long mode = OVERLAY;


void
run(Context_t *ctx)
{
  Pixel_t *src1, *start, *src2, *dst;

  dst = start = passive_buffer(ctx)->buffer;

  pthread_mutex_lock(&ctx->cam_mtx[ctx->cam]);
  src1 = ctx->cam_save[ctx->cam][0]->buffer;
  src2 = ctx->cam_ref0[ctx->cam]->buffer;
  for (; dst < start + BUFFSIZE * sizeof(Pixel_t); src1++, src2++, dst++) {
    if (((*src1 - *src2) > MIN_DIFFERENCE) ||
        ((*src2 - *src1) > MIN_DIFFERENCE) ) {
      *dst = abs(*src1 - *src2);
    } else {
      *dst = 0;
    }
  }
  pthread_mutex_unlock(&ctx->cam_mtx[ctx->cam]);
}
